@@ -45,7 +45,9 @@ class Media(ABC):
             _rtn = [self._redis.incr(name=_rtbl)]
         return _rtn
 
-    def _get_last_upd(self, type: str, page: int = 0, count: int = 50) -> list:
+    def _get_last_upd(self, type: str, page: int = None, count: int = None) -> list:
+        page = 0 if page is None else page
+        count = 50 if count is None else count
         _tbl = self.get_table(type, "update")
         _rtn = [int(_c.decode("UTF-8")) for _c in self._redis.zrevrangebyscore(
             name=_tbl, min=0, max=9999999999, start=page * count, num=count)]
@@ -391,6 +393,9 @@ class Media(ABC):
             type="videos", opt="index"), self._source, "id")
         _ppl_table = "{}:{}:{}".format(self.get_table(
             type="people", opt="index"), self._source, "id")
+        _pg = 0 if _page is None else int(_page)
+        _cnt = 50 if _count is None else int(_count)
+        _uids = _uids[(_pg * _cnt):((_pg + 1) * _cnt)]
         for _v in self._search(type=_type, keyval=_video, id=_videoid,
                                uid=_uids, page=_page, count=_count):
             _ppl_lst = []
